@@ -26,12 +26,12 @@
 create_beast2_input_file <- function(
   input_filename,
   output_filename,
-  site_model = create_jc69_site_model(),
-  clock_model = create_strict_clock_model(),
-  tree_prior = create_yule_tree_prior(),
+  site_model = beautier::create_jc69_site_model(),
+  clock_model = beautier::create_strict_clock_model(),
+  tree_prior = beautier::create_yule_tree_prior(),
   mrca_prior = NA,
-  mcmc = create_mcmc(),
-  beauti_options = create_beauti_options(),
+  mcmc = beautier::create_mcmc(),
+  beauti_options = beautier::create_beauti_options(),
   tipdates_filename = NA,
   input_filenames = "deprecated",
   site_models = "deprecated",
@@ -83,7 +83,7 @@ create_beast2_input_file <- function(
   if (any("mrca_priors" %in% calls)) {
     stop("'mrca_priors' is deprecated, use 'mrca_prior' instead.")
   }
-  inference_model <- create_inference_model(
+  inference_model <- beautier::create_inference_model(
     site_model = site_model,
     clock_model = clock_model,
     tree_prior = tree_prior,
@@ -92,7 +92,7 @@ create_beast2_input_file <- function(
     beauti_options = beauti_options,
     tipdates_filename = tipdates_filename
   )
-  create_beast2_input_file_from_model(
+  beautier::create_beast2_input_file_from_model(
     input_filename = input_filename,
     output_filename = output_filename,
     inference_model = inference_model
