@@ -24,12 +24,12 @@
 #' )
 #' @export
 create_inference_model <- function(
-  site_model = create_jc69_site_model(),
-  clock_model = create_strict_clock_model(),
-  tree_prior = create_yule_tree_prior(),
+  site_model = beautier::create_jc69_site_model(),
+  clock_model = beautier::create_strict_clock_model(),
+  tree_prior = beautier::create_yule_tree_prior(),
   mrca_prior = NA,
-  mcmc = create_mcmc(),
-  beauti_options = create_beauti_options(),
+  mcmc = beautier::create_mcmc(),
+  beauti_options = beautier::create_beauti_options(),
   tipdates_filename = NA
 ) {
   inference_model <- list(
