@@ -1,9 +1,19 @@
 #' Create an MCMC configuration.
 #'
 #' Create an MCMC configuration, as in the BEAUti MCMC tab.
-#' The number of states that will be saved equals the chain
-#' length (\code{chain_length}) divided by the number of
-#' states between each sampling event (\code{store_every})
+#'
+#' There are four things that can be saved:
+#'  * \code{store_every}: saves the state of the MCMC to file,
+#'    as a \code{.state.xml} file
+#'  * \code{tracelog}: stores the trace of the state of the MCMC
+#'    to file. See \code{create_tracelog}
+#'    how to specify the filename
+#'  * \code{screenlog}: stores the screen output
+#'    to file. See \code{create_screenlog}
+#'    how to specify the filename
+#'  * \code{treelog}: stores the estimated phylogenies
+#'    to file. See \code{create_treelog}
+#'    how to specify the filename
 #' @inheritParams default_params_doc
 #' @return an MCMC configuration
 #' @seealso
@@ -31,9 +41,9 @@ create_mcmc <- function(
   pre_burnin = 0,
   n_init_attempts = 10,
   sample_from_prior = FALSE,
-  tracelog = create_tracelog(),
-  screenlog = create_screenlog(),
-  treelog = create_treelog()
+  tracelog = beautier::create_tracelog(),
+  screenlog = beautier::create_screenlog(),
+  treelog = beautier::create_treelog()
 ) {
   mcmc <- list(
     chain_length = chain_length,
