@@ -3,10 +3,12 @@
 #' @seealso use \link{create_screenlog} to create a screenlog.
 #' @export
 create_temp_screenlog_filename <- function() {
-  tempfile(
-    pattern = "screenlog_",
-    tmpdir = rappdirs::user_cache_dir(),
-    fileext = ".csv"
+  normalizePath(
+    tempfile(
+      pattern = "screenlog_",
+      tmpdir = rappdirs::user_cache_dir(),
+      fileext = ".csv"
+    ),
+    mustWork = FALSE
   )
-
 }
