@@ -3,9 +3,12 @@
 #' @seealso use \link{create_tracelog} to create a tracelog.
 #' @export
 create_temp_tracelog_filename <- function() {
-  tempfile(
-    pattern = "tracelog_",
-    tmpdir = rappdirs::user_cache_dir(),
-    fileext = ".log"
+  normalizePath(
+    tempfile(
+      pattern = "tracelog_",
+      tmpdir = rappdirs::user_cache_dir(),
+      fileext = ".log"
+    ),
+    mustWork = FALSE
   )
 }
