@@ -3,9 +3,12 @@
 #' @seealso use \link{create_treelog} to create a treelog.
 #' @export
 create_temp_treelog_filename <- function() {
-  tempfile(
-    pattern = "treelog_",
-    tmpdir = rappdirs::user_cache_dir(),
-    fileext = ".trees"
+  normalizePath(
+    tempfile(
+      pattern = "treelog_",
+      tmpdir = rappdirs::user_cache_dir(),
+      fileext = ".trees"
+    ),
+    mustWork = FALSE
   )
 }
